package com.jeffknecht.dynadao.annotation;

import java.lang.annotation.Retention;
import java.lang.annotation.RetentionPolicy;

/**
 * Specifies the source data of a DTO
 * as coming from a select statement
 * instead of a table.  Use in lieu
 * of Table annotation for complex,
 * read-only data types.
 * 
 * @author jeff.knecht
 */
@Retention(RetentionPolicy.RUNTIME)
public @interface Select {
	/**
	 * A SQL FROM clause, without the keyword "from".
	 * 
	 * @return
	 */
	String from();
	
	/**
	 * A SQL WHERE clause, without the keyword "where".
	 */
	String where() default "";
	
	/**
	 * A SQL ORDER BY clause, without the keyword "where".
	 */
	String orderBy() default "";

	/**
	 * A SQL GROUP BY clause, without the keyword "where".
	 */
	String groupBy() default "";

	/**
	 * A SQL HAVING clause, without the keyword "where".
	 */
	String having() default "";

}
